==> fusenshi-0.8.5.tgz: fusenshi-0.8.5/src/include/fusenshi.h <==
/*
 * $Id: fusenshi.h,v 1.5 2007/03/02 13:02:41 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.5 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHI_H
#define ___FUSENSHI_H

#ifndef __cplusplus
#define __cplusplus
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <libintl.h>
#include <errno.h>

#ifndef _
#define _(TEXT)             gettext(TEXT)
#define N_(TEXT)            gettext_noop(TEXT)
#define gettext_noop(TEXT)  (TEXT)
#endif

#define __prepro__str(x)	#x
#define __prepro__xstr(x)	__prepro__str(x)

#include "../fio/fio.h"
#include "../net/net.h"
#include "../wnd/wnd.h"
#include "../misc/misc.h"

#define APP_NAME            "fusenshi"

#define TOP_WINDOW_WIDTH        36
#define TOP_WINDOW_HEIGHT       36
#define TRAYICON_WINDOW_WIDTH   26
#define TRAYICON_WINDOW_HEIGHT  26
#define WINDOW_TAG_WIDTH        20

#define MAX_FUSENSHI_NUM    999

#define PRINT_FILE_KEY            "%1"
#define DEFAULT_PRINT_COMMAND    ("lpr " PRINT_FILE_KEY)

#endif

==> fusenshi-0.9.0.tgz: fusenshi-0.9.0/src/include/fusenshi.h <==
/*
 * $Id: fusenshi.h,v 1.6 2007/06/25 06:19:21 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.6 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHI_H
#define ___FUSENSHI_H

#ifndef __cplusplus
#define __cplusplus
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <libintl.h>
#include <errno.h>

#ifndef _
#define _(TEXT)             gettext(TEXT)
#define N_(TEXT)            gettext_noop(TEXT)
#define gettext_noop(TEXT)  (TEXT)
#endif

#define __prepro__str(x)	#x
#define __prepro__xstr(x)	__prepro__str(x)

#include "../fio/fio.h"
#include "../net/net.h"
#include "../wnd/wnd.h"
#include "../misc/misc.h"

#define APP_NAME            "fusenshi"

#define TOP_WINDOW_WIDTH        36
#define TOP_WINDOW_HEIGHT       36
#define TRAYICON_WINDOW_WIDTH   26
#define TRAYICON_WINDOW_HEIGHT  26
#define WINDOW_TAG_WIDTH        20

#define MAX_FUSENSHI_NUM        999
#define MAX_FUSENSHI_PAGENUM    20

#define PRINT_FILE_KEY            "%1"
#define DEFAULT_PRINT_COMMAND    ("lpr " PRINT_FILE_KEY)

#endif
